==> querydsl-parser-0.1-sources.jar: foundation/jpa/querydsl/State.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.StateBase;

// Generated visitor pattern based state for grammar parser.
public class State extends StateBase<com.querydsl.core.types.Predicate> {
    private final foundation.jpa.querydsl.QueryFactory factory;

    public State(foundation.jpa.querydsl.QueryFactory factory) {
        this.factory = factory;
    }

    public foundation.jpa.querydsl.QueryFactory getFactory() {
        return factory;
    }

// Ignored:
    public State visitWhiteSpace(foundation.rpg.common.symbols.WhiteSpace symbol) {
        return this;
    }


// Symbols:
    public State visitEnd(foundation.rpg.parser.End symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitNot(foundation.rpg.common.symbols.Not symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitLPar(foundation.rpg.common.symbols.LPar symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitIn(foundation.rpg.common.symbols.In symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitComma(foundation.rpg.common.symbols.Comma symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitDouble(java.lang.Double symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitInteger(java.lang.Integer symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitString(java.lang.String symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitIdentifier(foundation.rpg.common.symbols.Identifier symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitDot(foundation.rpg.common.symbols.Dot symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitPredicate(com.querydsl.core.types.Predicate symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitLogicalOrBooleanExpression(com.querydsl.core.types.dsl.BooleanExpression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitLogicalAndBooleanExpression(com.querydsl.core.types.dsl.BooleanExpression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitRelationalBooleanExpression(com.querydsl.core.types.dsl.BooleanExpression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitCommaSeparatedListOfExpression(java.util.List<com.querydsl.core.types.Expression> symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitCommaSeparatedNonEmptyListOfExpression(java.util.List<com.querydsl.core.types.Expression> symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitExpression(com.querydsl.core.types.Expression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitObject(java.lang.Object symbol) throws UnexpectedInputException {
        return error(symbol);
    }


}

==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/State.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.StateBase;

// Generated visitor pattern based state for grammar parser.
public class State extends StateBase<com.querydsl.core.types.Predicate> {
    private final foundation.jpa.querydsl.QueryFactory factory;

    public State(foundation.jpa.querydsl.QueryFactory factory) {
        this.factory = factory;
    }

    public foundation.jpa.querydsl.QueryFactory getFactory() {
        return factory;
    }

// Ignored:
    public State visitWhiteSpace(foundation.rpg.common.symbols.WhiteSpace symbol) {
        return this;
    }


// Symbols:
    public State visitEnd(foundation.rpg.parser.End symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitNot(foundation.rpg.common.symbols.Not symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitLPar(foundation.rpg.common.symbols.LPar symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitIs(foundation.rpg.common.symbols.Is symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitNull(foundation.rpg.common.symbols.Null symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitIn(foundation.rpg.common.symbols.In symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitComma(foundation.rpg.common.symbols.Comma symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitDouble(java.lang.Double symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitInteger(java.lang.Integer symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitString(java.lang.String symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitIdentifier(foundation.rpg.common.symbols.Identifier symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitDot(foundation.rpg.common.symbols.Dot symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitPredicate(com.querydsl.core.types.Predicate symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitLogicalOrBooleanExpression(com.querydsl.core.types.dsl.BooleanExpression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitLogicalAndBooleanExpression(com.querydsl.core.types.dsl.BooleanExpression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitRelationalBooleanExpression(com.querydsl.core.types.dsl.BooleanExpression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitCommaSeparatedListOfExpression(java.util.List<com.querydsl.core.types.Expression> symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitCommaSeparatedNonEmptyListOfExpression(java.util.List<com.querydsl.core.types.Expression> symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitExpression(com.querydsl.core.types.Expression symbol) throws UnexpectedInputException {
        return error(symbol);
    }

    public State visitObject(java.lang.Object symbol) throws UnexpectedInputException {
        return error(symbol);
    }


}
